 {{-- @extends('layouts.app') --}}
 @extends('layouts.sidebar')

 @section('content')
     <!-- content -->

     {{-- {{ $repuestos }} --}}
     <style>
         .narrow-input {
             width: 30px;
             /* Puedes ajustar este valor según tus necesidades */
             text-align: center;

         }


         #modalDescuento {
             position: fixed;
             bottom: 0;
             left: 0;
             right: 0;
             margin: 0;
         }
     </style>
     <div class="titulos">
         <h2>Orden de trabajo Nº : {{ $numeroOt }}
             @if ($ordenes_trabajos[0]->descripcionestado == 'finalizada')
                 -- FINALIZADA
             @endif
             <hr />

     </div>
     {{-- {{$servicios_ordenes}} --}}
     <div class="container">
         <h3>Editar OT</h3>

         <form action="{{ route('ordendetrabajo.editandostore') }}" id="formuarioeditar" method="POST">
             @csrf
             <input type="text" hidden value="{{ $numeroOt }}" name="numeroOt" id="">
             <input type="text" hidden value="{{ $idOrdenTrabajo }}" name="idOrdenTrabajo" id="">




             <input type="text" hidden name="id_cliente" value="{{ $idCliente ?? '' }}">
             <div class="row card">
                 <div class="card-header">
                     Datos del contacto
                 </div>
                 {{-- datos personales --}}
                 <div class="row">
                     <div class="mb-3 col-6">
                         <label for="razon_social" class="form-label">Razon Social</label>
                         <input type="text" required class="form-control" id="razon_social"
                             value="{{ $ordenes_trabajos[0]->razon_social ?? '' }}" disabled placeholder=""
                             name="razon_social">

                     </div>
                     <div class="mb-3 col-6">
                         <label for="" class="form-label">Rut</label>
                         <input type="text" value="{{ $ordenes_trabajos[0]->rut ?? '' }}" disabled required
                             class="form-control" id="" placeholder="" name="">

                     </div>
                     <div class="mb-3 col-6">
                         <label for="" class="form-label">Correo</label>
                         <input type="text" value="{{ $ordenes_trabajos[0]->correo ?? '' }}" disabled required
                             class="form-control" id="" placeholder="" name="">

                     </div>
                     <div class="mb-3 col-6">
                         <label for="" class="form-label">Telefono</label>
                         <input type="text" value="{{ $ordenes_trabajos[0]->telefono ?? '' }}" disabled required
                             class="form-control" id="" placeholder="" name="">

                     </div>
                     <hr>
                     <strong><label for="">Ejecutar orden</label></strong>
                     <hr>
                     {{-- {{ $ordenes_trabajos }} --}}
                     <div class="mb-3 col-6">
                         <label for="" class="form-label">Operario encargado</label>
                         <select class="form-control mayuscula" name="operario" id="operario">
                             <option value="">Seleccionares</option>
                             {{-- id_user --}}
                             @if (!empty($operarios))
                                 @foreach ($operarios as $data)
                                     @if ($ordenes_trabajos[0]->id_user == $data->id_user)
                                         <option value="{{ $data->id_user }}" selected>{{ $data->nombre }}
                                             {{ $data->apellido }}</option>
                                     @else
                                         <option value="{{ $data->id_user }}">{{ $data->nombre }}
                                             {{ $data->apellido }}</option>
                                     @endif
                                 @endforeach
                             @endif
                         </select>

                     </div>

                     <div class="mb-3 col-3">
                        <label for="" class="form-label">Fecha Ingreso</label>
                        @if (isset($ordenes_trabajos[0]->fecha_ingreso))
                            <input type="date" name="fecha_ingreso" class="form-control"
                                value="{{ \Carbon\Carbon::createFromDate($ordenes_trabajos[0]->fecha_ingreso)->format('Y-m-d') }}">
                        @else
                            <input type="date" name="fecha_ingreso" class="form-control" value="">
                        @endif
                    
                    </div>


                     <div class="mb-3 col-3">
                        <label for="" class="form-label">Fecha entrega</label>
                        @if (isset($ordenes_trabajos[0]->fecha_entrega))
                            <input type="date" name="fechaentrega" class="form-control"
                                value="{{ \Carbon\Carbon::createFromDate($ordenes_trabajos[0]->fecha_entrega)->format('Y-m-d') }}">
                        @else
                            <input type="date" name="fechaentrega" class="form-control" value="">
                        @endif
                    
                    </div>

                     {{-- <div class="mb-3 col-6">
                         <label for="" class="form-label">Fecha entrega</label>
                         @if (isset($ordenes_trabajos[0]->fecha_entrega))
                             <input type="date" name="fechaentrega" class="form-control"
                                 value="{{ \Carbon\Carbon::createFromDate($ordenes_trabajos[0]->fecha_entrega)->format('Y-m-d') }}">
                         @else
                             <input type="date" name="fechaentrega" class="form-control" value="">
                         @endif
                     
                     </div> --}}
                     {{-- value="{{Carbon\Carbon::createFromDate($orden_trabajo[0]->fecha_entrega ?? '')->format('d-m-Y')}}" --}}
                     <div class="mb-3 col-13">
                         <label for="" class="form-label">Comentario</label>

                         <textarea name="comentario" class="form-control text-uppercase" id="" cols="3" rows="3">{{ $ordenes_trabajos[0]->observacion }}</textarea>

                     </div>





                     <div class="row">
                         <hr>
                         <label for="" class="m-2"> Datos del motor</label>

                         {{-- <div class="mb-3 col-3">
                    <label for="razon_social" class="form-label">Responsable</label>
                    <input type="text" required class="form-control" id="razon_social"
                        value="{{ $datosdelequipo[0]->responsable ?? '' }}" disabled placeholder=""
                        name="razon_social">

                </div> --}}
                <div class="mb-3 col-3">
                    <label for="marca" class="form-label">Marca</label>
                    <input type="text"  class="form-control" id="marca"
                        value="{{ $datosdelequipo[0]->marca ?? '' }}"  placeholder="" name="marca">

                </div>
                <div class="mb-3 col-3">
                    <label for="modelo" class="form-label">Modelo</label>
                    <input type="text"  class="form-control" id="modelo"
                        value="{{ $datosdelequipo[0]->modelo ?? '' }}"  placeholder=""
                        name="modelo">

                </div>
                <div class="mb-3 col-3">
                    <label for="motor" class="form-label">Motor</label>
                    <input type="text"  class="form-control" id="motor"
                        value="{{ $datosdelequipo[0]->motor ?? '' }}"  placeholder=""
                        name="motor">

                </div>
                <div class="mb-3 col-3">
                    <label for="ano_auto" class="form-label">Año</label>
                    <input type="text"  class="form-control" id="ano_auto"
                        value="{{ $datosdelequipo[0]->ano ?? '' }}"  placeholder=""
                        name="ano_auto">

                </div>
                <div class="mb-3 col-3">
                    <label for="serie" class="form-label">Serie</label>
                    <input type="text"  class="form-control" id="serie"
                        value="{{ $datosdelequipo[0]->serie ?? '' }}"  placeholder=""
                        name="serie">

                </div>
             
                <div class="col-md mt-2">
                   <label for="">Combustible</label>
                   <select class="form-control mayuscula" id="equipo_combustible" name="combustible"
                       id="combustible">
                       <option value="">Seleccionar</option>
                       @if (!empty($combustibles))
                           @foreach ($combustibles as $data)

                           @if($datosdelequipo[0]->idcombustible  ==   $data->id)
                               <option selected value="{{ $data->id }}">
                                   {{ $data->nombre }}</option>

                            @else
                            <option  value="{{ $data->id }}">
                               {{ $data->nombre }}</option>
                            
                            @endif
                           @endforeach
                       @endif
                   </select>
               </div>
                
                {{-- <div class="mb-3 col-3">
                             <label for="razon_social" class="form-label">Marca</label>
                             <input type="text" required class="form-control" id="razon_social"
                                 value="{{ $datosdelequipo[0]->marca ?? '' }}" disabled placeholder="" name="razon_social">

                         </div>
                         <div class="mb-3 col-3">
                             <label for="razon_social" class="form-label">Modelo</label>
                             <input type="text" required class="form-control" id="razon_social"
                                 value="{{ $datosdelequipo[0]->modelo ?? '' }}" disabled placeholder=""
                                 name="razon_social">

                         </div>
                         <div class="mb-3 col-3">
                             <label for="razon_social" class="form-label">Motor</label>
                             <input type="text" required class="form-control" id="razon_social"
                                 value="{{ $datosdelequipo[0]->motor ?? '' }}" disabled placeholder=""
                                 name="razon_social">

                         </div>
                         <div class="mb-3 col-3">
                             <label for="razon_social" class="form-label">Año</label>
                             <input type="text" required class="form-control" id="razon_social"
                                 value="{{ $datosdelequipo[0]->ano ?? '' }}" disabled placeholder=""
                                 name="razon_social">

                         </div>
                         <div class="mb-3 col-3">
                             <label for="razon_social" class="form-label">Serie</label>
                             <input type="text" required class="form-control" id="razon_social"
                                 value="{{ $datosdelequipo[0]->serie ?? '' }}" disabled placeholder=""
                                 name="razon_social">

                         </div>
                         <div class="mb-3 col-3">
                             <label for="razon_social" class="form-label">Combustible</label>
                             <input type="text" required class="form-control" id="razon_social"
                                 value="{{ $datosdelequipo[0]->nombrecombustible ?? '' }}" disabled placeholder=""
                                 name="razon_social">

                         </div> --}}
                         {{-- <div class="mb-3 col-3">
                    <label for="razon_social" class="form-label">Patente</label>
                    <input type="text" required class="form-control" id="razon_social"
                        value="{{ $datosdelequipo[0]->patente ?? '' }}" disabled placeholder=""
                        name="razon_social">

                </div> --}}
                     </div>

                 </div> {{-- fin del card --}}



                 {{-- DATOS DE SERVICIOS         --}}
                 <br>
                 <div class=" card mb-3  mt-3">
                     <div class="card-header m3-3 d-flex align-items-center ">
                        Servicio
                        <a style="cursor: pointer" data-bs-toggle="modal" data-bs-target="#modalSelectServicios"> <span class="material-symbols-outlined">
                            search
                        </span></a> 
                     </div>
                     <div class="row">

                         <div class="col-12 form-group">
                             <div class="row m-2">
                                 <div class="col ">
                                     <label for="">Sku</label>

                                     <input type="text" class="form-control mayuscula" id="campoServicio"
                                         placeholder="Servicio" name="SKU" value=""
                                         onkeydown="buscarServicioFunction(event)">
                                 </div>
                                 <div class="col">
                                     <label for="">Nombre servicio</label>

                                     <input type="text" disabled class="form-control mayuscula"
                                         id="nombredelservicio">
                                 </div>
                                 <div class="col">
                                     <label for="">Descripción</label>

                                     <input type="text" class="form-control mayuscula" id="campoServicioDescripcion"
                                         placeholder="Descripcion" name="servicio" value=""
                                         onkeydown="buscarServicioFunctionDesc(event)">

                                 </div>
                                 <div class="col">
                                     <label for="">Cantidad</label>

                                     <input type="text" onkeypress='soloNumeros(event)' class="form-control mayuscula"
                                         id="campoServicioCantidad" placeholder="Cantidad" name="servicio"
                                         value="" onkeydown="buscarServicioFunctionCan(event)">

                                 </div>
                                 {{-- <div class="col">
                                 <input type="" class="form-control mayuscula" id=""
                                 placeholder="Servicio" name="" value="">
                                </div> --}}
                             </div>
                             <!-- <label for="">Servicio</label> -->
                             {{-- <input type="" class="form-control mayuscula" id="nombre_servicio"
                                placeholder="Servicio" name="" value=""> --}}
                         </div>
                         <div class="col-12 form-group" id="">
                             <table class="table table-hover">
                                 <tbody id="tableservicios"></tbody>
                             </table>
                         </div>


                         <div>

                             <div>

                             </div>

                             @if (session('success_servicios'))
                                 <div class="alert alert-success">
                                     {{ session('success_servicios') }}
                                 </div>
                             @endif
                             <table class="table2 table-hover " >
                                 <thead class="bg-light">
                                     <th scope="col">Codigo</th>

                                     <th scope="col">Servicios</th>
                                     <th scope="col">Descripcion </th>

                                     <th scope="col">Categoria</th>

                                     {{-- <th scope="col">Tecnico Asignado</th> --}}
                                     <th scope="col">Cantidad</th>
                                     <th scope="col">Neto</th>
                                     <th scope="col">Total</th>

                                     <th scope="col">Estado</th>
                                     {{-- <th scope="col">Descuento</th> --}}
                                     {{-- <th scope="col"></th> --}}

                                     <th scope="col">

                                        <span class="material-symbols-outlined">
                                            settings
                                            </span>

                                     </th>


                                 </thead>
                                 {{-- {{$servicios_ordenes}} --}}
                                 <tbody id="tabla_servicios_selecionados">

                                     @if (!empty($servicios_ordenes))
                                         @foreach ($servicios_ordenes as $los_datos)
                                             <tr>
                                                 <td class="td-val text-uppercase">
                                                     {{ $los_datos->sku }}
                                                 </td>
                                                 <td class="td-val text-uppercase">
                                                     {{ $los_datos->nombre_servicio }}<br>{{ $los_datos->descripcion }}
                                                 </td>
                                                 <td class="td-val text-uppercase">
                                                     {{ $los_datos->descripcionservicio }}
                                                 </td>
                                                 <td class="td-val text-uppercase">
                                                     {{ $los_datos->categoria }}
                                                 </td>
                                                 <td class="td-val text-uppercase">

                                                     @if ($los_datos->tecnicos_id == 1)
                                                         No registrado
                                                     @else
                                                         {{ \App\Models\User::datosTecnicoUser($los_datos->tecnicos_id) }}
                                                     @endif

                                                 </td>
                                                 <td class="td-val text-uppercase">{{ $los_datos->cantidad }}</td>
                                                 <td class="td-val text-uppercase">{{ $los_datos->estado_ejecucion }}</td>


                                                 @if ($ordenes_trabajos[0]->descripcionestado == 'INICIADA' || $ordenes_trabajos[0]->descripcionestado == 'FINALIZADA')
                                                     <td>


                                                         @if ($los_datos->tecnicos_id == 1)
                                                             <a title="Agregar Tecnico" style="cursor: pointer">
                                                                 <span class="material-symbols-outlined">
                                                                     <span class="material-symbols-outlined"
                                                                         onclick="registrarTecnico({{ $los_datos->id_ejecucion_servicio }},{{ $los_datos->id_servicio_orden }})">
                                                                         add_circle

                                                                     </span>
                                                             </a>
                                                         @else
                                                             @if ($los_datos->estado_ejecucion == 'finalizado')
                                                             @else
                                                                 {{-- validamos si ya esta iniciado o no  --}}

                                                                 @if ($los_datos->estado_ejecucion == 'procesando')
                                                                     <a title="Finalizar Servicio" style="cursor: pointer"
                                                                         onclick="updateservicio({{ $los_datos->id_ejecucion_servicio }},{{ $los_datos->id_servicio_orden }},'finalizar')">
                                                                         <span class="material-symbols-outlined">
                                                                             check_circle
                                                                         </span>
                                                                     </a>
                                                                 @else
                                                                     <a title="Iniciar Servicio" style="cursor: pointer"
                                                                         onclick="updateservicio({{ $los_datos->id_ejecucion_servicio }},{{ $los_datos->id_servicio_orden }},'iniciar')">
                                                                         <span class="material-symbols-outlined">
                                                                             play_circle
                                                                         </span>
                                                                     </a>
                                                                 @endif
                                                             @endif
                                                         @endif



                                                         <a>
                                                             <span class="material-symbols-outlined"
                                                                 onclick="openhistorial({{ $los_datos->id_servicio_orden }})">
                                                                 overview
                                                             </span>
                                                         </a>



                                                     </td>
                                                 @endif
                                                 {{-- EN PROCESO SOLO MOSTRARA y fiinalizada --}}

                                             </tr>
                                         @endforeach
                                     @endif

                                 </tbody>
                             </table>
                             <input type="text" hidden id="arrayDatosTabla" name="arrayDatosTabla">
                         </div>

                     </div>{{-- fin del row --}}
                 </div>{{-- fin del card --}}



                 {{-- DATOS DE REPUESTOS         --}}

                 <div class=" card  mb-3 mr-3 mt-3">
                     <div class="card-header m3-3 ">
                         Repuestos
                     </div>
                     <div class="row">

                         <div class="col-12 form-group">
                             <!-- <label for="">Repuestos solicitados</label> -->
                             {{-- <input type="" class="form-control mayuscula" id="nombre_repuesto"
                                 placeholder="Repuestos solicitados" name="" value=""> --}}
                                 @foreach ($repuestos as $data)

                                 {{-- <div>
                                  <input type="checkbox" name="" id="" value="{{$data->nombre}}">{{$data->nombre}}
                                 </div> --}}
                                 <div style="display: inline-block; margin-right: 20px;">
                                  <input type="checkbox" name="" onclick="actualizarTable({{$data->id}})" id="check_{{$data->id}}" value="{{$data->nombre}}">
                                  <label style="cursor: pointer"  for="check_{{$data->id}}">{{$data->nombre}}</label>
                              </div>
                                  @endforeach
                         </div>
                         <div class="col-12 form-group" id="">
                             <table class="table table-hover">
                                 <tbody id="tablerepuestos"></tbody>
                             </table>
                         </div>


                         <div>
                             <table class="table table-hover">
                                 <thead class="bg-light">
                                     <th scope="col">Repuesto</th>
                                     <th scope="col">Medidas</th>

                                     <th scope="col">Categoria</th>
                                     <th scope="col">Cantidad</th>


                                     <th scope="col">Acciones</th>


                                 </thead>
                                 <tbody id="tabla_repuesto_selecionados">
                                     {{--
                                @if (!empty($repuestos_solicitados))
                                    @foreach ($repuestos_solicitados as $los_datos)
                                        <td class="td-val text-uppercase">
                                            {{ $los_datos->nombre }}
                                        </td>
                                        <td class="td-val text-uppercase">
                                            {{ $los_datos->categoria }}
                                        </td>
                                        <td class="td-val text-uppercase">
                                            {{ $los_datos->cantidad }}
                                        </td>
                                        <td class="td-val text-uppercase">
                                            @if ($los_datos->recibido == 'si')
                                                <input type="checkbox"  name="" checked id="">
                                            @else
                                            <input type="checkbox" onclick="addRepuestos({{ $los_datos->idrepuestossolicitados }})" name=""  id="">

                                            @endif --}}
                                     {{-- {{ $los_datos->recibido }} --}}
                                     {{-- </td>
                                        @if ($ordenes_trabajos[0]->descripcionestado == 'En proceso' || $ordenes_trabajos[0]->descripcionestado == 'finalizada')

                                                <td>

                                                    <a title="Finalizar Servicio" style="cursor: pointer"
                                                        onclick="openModalRepuestos({{ $los_datos->idrepuestossolicitados }})">
                                                        <span class="material-symbols-outlined">
                                                            overview
                                                        </span>
                                                    </a>
                                                </td>
                                         @endif

                                        <tr>
                                        </tr>
                                    @endforeach
                                @endif --}}
                                 </tbody>
                             </table>
                             <input type="" hidden id="arrayDatosTablaRepuestos" name="arrayDatosTablaRepuestos">
                         </div>

                     </div>{{-- fin del row --}}
                 </div>{{-- fin del card --}}
                 {{-- {{$ordenes_trabajos}} --}}


                 <br>
                 <br>

                 <div class="row">
                     <h4>Datos Pago</h4>

                     {{-- SUB TOTAL --}}
                     <div>
                         <strong> <label for="">Sub Total:</label> </strong> <label for=""
                             id="l_subtotal"></label>
                     </div>

                     {{-- IMPUESTO AL SUBTOTAL --}}
                     <div>
                         <strong> <label for="">Impuesto:</label> </strong> <label for=""
                             id="l_impuestoTotal"></label>
                     </div>

                     {{-- TOTAL MAS IMPUESTO --}}
                     <div>
                         <strong> <label for="">Total:</label> </strong> <label for=""
                             id="l_totalmasimpuesto"></label>
                     </div>
                     {{-- DESUENTO --}}

                     <div>
                         <strong>
                             <label for="">Descuento(%):
                                <a data-bs-toggle="modal" data-bs-target="#modalDescuento">
                                    <span class="material-symbols-outlined">
                                        edit
                                    </span>
                                </a>

                             </label>
                         </strong>
                         <label for="" id="l_descuento">{{ $ordenes_trabajos[0]->descuento_porcentaje }}</label>
                     </div>
                     {{-- DESCUENTO --}}

                     <div>
                         <strong>
                            <label for="">Descuento($):
                                <a data-bs-toggle="modal" data-bs-target="#modalDescuentoTotal">
                                    <span class="material-symbols-outlined">
                                        edit
                                    </span>
                                </a>

                            </label>
                         </strong>
                         <label for=""
                             id="l_descuento_sin_porcentaje">{{ \App\Models\config::formatNumberWithCommas($ordenes_trabajos[0]->descuento_pesos) }}</label>
                     </div>
                     {{-- NETO --}}

                     <div>
                         <strong> <label style="color: red" for="">Neto subtotal:</label> </strong> <label for=""
                             id="l_totalnetoNuevo">{{ \App\Models\config::formatNumberWithCommas($ordenes_trabajos[0]->neto_descuentos) }}</label>
                     </div>
                     {{-- IMPUESTO --}}

                     <div>
                         <strong> <label style="color: red" for="">Impuesto:</label> </strong> <label
                             for="" id="l_impuestoTotalNuevo">{{ \App\Models\config::formatNumberWithCommas($ordenes_trabajos[0]->impuesto_al_descuento) }}</label>
                     </div>
                     {{-- TOTAL CON DESCUENTO --}}

                     <div>
                         <strong> <label style="font-weight: bold; color: black;" for="">Total con
                                 descuento:</label> </strong> <label style="font-weight: bold; color: black;"
                             for="" id="l_totalcondescuento">{{ \App\Models\config::formatNumberWithCommas($ordenes_trabajos[0]->total_con_descuentos) }}</label>
                     </div>
                     <div>
                         <strong>
                             <label for="">Abono:</label>

                         </strong>
                         <label for="" id="l_abono">{{ $ordenes_trabajos[0]->abono }}</label>
                     </div>

                     <div>
                         <strong> <label for="">Pendiente:</label> </strong> <label for=""
                             id="l_pendiente">
                             {{ \App\Models\config::formatNumberWithCommas($ordenes_trabajos[0]->pendiente) }}
                            </label>
                     </div>
                 </div>{{-- fin del row --}}



                 {{-- DATOS POR ENVIAR --}}
                 <input type="text" hidden name="input_abono" id="input_abono">
                 <input type="text" hidden  name="input_descuento" id="input_descuento">
                 <input type="text" hidden name="input_metodopago" id="input_metodopago">



{{-- {{$ordenes_trabajos[0]->descripcionestado}} --}}
                 @if ($ordenes_trabajos[0]->descripcionestado != 'facturada' && $ordenes_trabajos[0]->descripcionestado != 'finalizada' && $ordenes_trabajos[0]->descripcionestado != 'cancelada')

                 <input type="submit" value="Guardar" class="btn btn-success col-md-3">
                 @endif
         </form>{{-- INICIO FORMULARIO --}}





     </div> {{-- FIN container --}}

     {{-- MODAL --}}



     <!-- Modal Tecnico -->
     <div class="modal" id="modalAddTecnico">
         <div class="modal-dialog">
             <div class="modal-content">

                 <!-- Modal Header -->
                 <div class="modal-header">
                     <h4 class="modal-title">Seleccionar Tecnico</h4>

                 </div>

                 <!-- Modal body -->
                 <div class="modal-body">

                     <form action="{{ route('update.updateservicioorden') }}" method="POST">
                         @csrf

                         <div class="m-2">

                             <select required name="tecnicoselecionado" class="form-control" id="">
                                 <option value="">Seleccionar</option>
                                 @if (!empty($tecnicos))
                                     @foreach ($tecnicos as $data)
                                         <option value="{{ $data->id_tecnico }}">
                                             {{ $data->nombre }}
                                             {{ $data->apellido }}
                                         </option>
                                     @endforeach
                                 @endif
                             </select>

                             <input type="text" hidden name="identificador_servicio_eje"
                                 id="identificador_servicio_eje">
                             <input type="text" hidden name="id_servicio_orden" id="id_servicio_orden">




                         </div>
                         <div class="m-2" style="text-align: right">
                             <button type="button" class="btn btn-danger" data-bs-dismiss="modalAddTecnico"
                                 onclick="cerrarModal()">Cerrar</button>

                             <button type="submit" class="btn btn-success" data-bs-dismiss="modal">Guarda</button>

                         </div>
                     </form>
                 </div>
             </div>
         </div>
     </div>
     <!-- Modal Descuento -->
<div class="modal" id="modalDescuentoTotal">
    <div class="modal-dialog">
        <div class="modal-content">

            <!-- Modal Header -->
            <div class="modal-header">
                <h4 class="modal-title">Descuento</h4>
                <button type="button" class="btn-close" data-bs-dismiss="modal"></button>
            </div>

            <!-- Modal body -->
            <div class="modal-body">
                <div class="m-2">
                    <input type="number" class="form-control" value=""  onkeydown="funcionPorcentajeAplicadoPesos(event)" id="dscuentoTotalAplicadoT">

                </div>
                <div class="m-2" style="text-align: right">
                    <button type="button" class="btn btn-success" data-bs-dismiss="modal"
                        onclick="aplicarDescuentoTotal();">Aplicar</button>

                </div>
            </div>
        </div>
    </div>
</div>
    
       <!-- Modal Descuento -->
    <div class="modal" id="modalDescuento">
        <div class="modal-dialog">
            <div class="modal-content">

                <!-- Modal Header -->
                <div class="modal-header">
                    <h4 class="modal-title">Descuento Porcentaje</h4>
                    <button type="button" class="btn-close" data-bs-dismiss="modal"></button>
                </div>

                <!-- Modal body -->
                <div class="modal-body">
                    <div class="m-2">
                        <input type="number" class="form-control"  onkeydown="funcionPorcentajeAplicado(event)" value="" id="porcentajeAplicado">

                    </div>
                    <div class="m-2" style="text-align: right">
                        <button type="button" class="btn btn-success" data-bs-dismiss="modal"
                            onclick="aplicarDescuento();">Aplicar</button>

                    </div>
                </div>
            </div>
        </div>
    </div>
     {{-- MODAL Repuestos --}}
     <div class="modal" id="modalRepuestos">
         <div class="modal-dialog">
             <div class="modal-content">

                 <!-- Modal Header -->
                 <div class="modal-header">
                     <h4 class="modal-title">Repuestos</h4>
                     <button type="button" class="btn-close" onclick="cerrarmodal()"></button>
                 </div>

                 <!-- Modal body -->
                 <div class="modal-body">
                     <div class="m-2">
                         <label for="">Recibido por</label>



                         <input type="text" class="form-control" id="recibidopor">


                     </div>
                     <div class="m-2">
                         <label for="">Comentario</label>
                         <textarea name="" id="comentario_entrega" class="form-control text-uppercase " cols="30"
                             rows="10"></textarea>

                     </div>
                     <div class="m-2" style="text-align: right">
                         <button type="button" class="btn btn-success" data-bs-dismiss="modal"
                             onclick="updaterepuestos();">Guardar</button>

                     </div>
                 </div>



             </div>
         </div>
     </div>

     {{-- MODAL HSTORIAL --}}
     <div class="modal" id="modalHistorial">
         <div class="modal-dialog modal-md">
             <div class="modal-content">

                 <!-- Modal Header -->
                 <div class="modal-header">
                     <h4 class="modal-title">Historial</h4>
                     <button type="button" class="btn-close" onclick="cerrarmodalhistorial()"></button>
                 </div>

                 <!-- Modal body -->
                 <div class="modal-body">
                     <div class="m-2">
                         <label for="">Historial</label>

                         <table class="table table-bordered">
                             <thead>
                                 <tr>
                                     <th>ID</th>
                                     <th>Fecha Ingresado</th>
                                     <th>Descripción</th>
                                     {{-- <th>Servicios Órdenes ID</th> --}}
                                 </tr>
                             </thead>
                             <tbody id="tablaBody">
                             </tbody>
                         </table>
                     </div>

                     <div class="m-2" style="text-align: right">
                         <button type="button" class="btn btn-success" data-bs-dismiss="modal"
                             onclick="cerrarmodalhistorial();">Cerrar</button>

                     </div>
                 </div>
             </div>
         </div>
     </div>

        <!-- Modal Servicios -->
        <div class="modal" id="modalSelectServicios">
            <div class="modal-dialog">
                <div class="modal-content">
    
                    <!-- Modal Header -->
                    <div class="modal-header">
                        <h4 class="modal-title">Servicio</h4>
                        <button type="button" class="btn-close" data-bs-dismiss="modal"></button>
                    </div>
    
                    <!-- Modal body -->
                    <div class="modal-body">
                        <div class="col-12 form-group">
                            {{-- <input type="" value="" class="form-control mayuscula" id="nombre_servicio"
                                placeholder="Servicio" name="" value=""> --}}
                                <input type="text" id="searchInput" class="form-control mayuscula"  placeholder="Buscar...">

                                <span id="faltaServicio"  style="display: none"><label for="" style="color: red">Debe seleccionar almenos un servicio</label></span>
                        </div>
                        <div class="table-scroll table-responsive">
                            <table class="table table-hover">
                                <tbody id="tableservicios">
                                    {{-- {{$servicios}} --}}
                                    @foreach ($servicios as $los_datos)
                                        <tr>
                                            <td class="td-val" onclick="agregarBuscador({{$los_datos->sku}})">{{$los_datos->sku}} || {{$los_datos->nombre_servicio}}</td>
                                        </tr>
                                    @endforeach
                                </tbody>
                            </table>
                        </div>
                    </div>
                </div>
            </div>
        </div>
     {{-- MODAL HISTORIAL REPUESTOS --}}
     <div class="modal" id="modalHistorialRepustos">
         <div class="modal-dialog modal-md">
             <div class="modal-content">

                 <!-- Modal Header -->
                 <div class="modal-header">
                     <h4 class="modal-title">Historial</h4>
                     <button type="button" class="btn-close" onclick="closedModalRepuestos()"></button>
                 </div>

                 <!-- Modal body -->
                 <div class="modal-body">
                     <div class="m-2">
                         <label for="">Historial</label>

                         <table class="table table-bordered">
                             <thead>
                                 <tr>
                                     <th>ID</th>
                                     <th>Fecha Ingresado</th>
                                     <th>Descripción</th>
                                     {{-- <th>Servicios Órdenes ID</th> --}}
                                 </tr>
                             </thead>
                             <tbody id="tablaBodyRepuestos">
                             </tbody>
                         </table>
                     </div>

                     <div class="m-2" style="text-align: right">
                         <button type="button" class="btn btn-success" data-bs-dismiss="modal"
                             onclick="closedModalRepuestos();">Cerrar</button>

                     </div>
                 </div>
             </div>
         </div>
     </div>

     {{-- //modals --}}

   

     {{-- MODAL ABONO --}}
     <div class="modal" id="modalAbono">
         <div class="modal-dialog">
             <div class="modal-content">

                 <!-- Modal Header -->
                 <div class="modal-header">
                     <h4 class="modal-title">Abono</h4>
                     <button type="button" class="btn-close" data-bs-dismiss="modal"></button>
                 </div>

                 <!-- Modal body -->
                 <div class="modal-body">
                     <div class="m-2">
                         <label for="">Total</label>

                         <input type="number" class="form-control" value="" id="abono">

                     </div>
                     <div class="m-2">
                         <label for="">Medio de pago</label>
                         <select name="" class="form-control" id="mediosPagosSelect">
                             <option value="">Seleccionar</option>
                             @if (!empty($medios_pagos))
                                 @foreach ($medios_pagos as $data)
                                     <option value="{{ $data->id }}"
                                         {{ old('modopago') == $data->id ? 'selected' : '' }}>{{ $data->descripcion }}
                                         {{ $data->apellido }}</option>
                                 @endforeach
                             @endif
                         </select>

                     </div>
                     <div class="m-2" style="text-align: right">
                         <button type="button" class="btn btn-success" data-bs-dismiss="modal"
                             onclick="aplicarAbono();">Aplicar</button>

                     </div>
                 </div>



             </div>
         </div>
     </div>
     <script>
         //VARIABLES GLOBALES


         var resultadoServicios = "";
         var resultadoServiciosSeleccionados = @json($servicios_ordenes);
         var resultadoRepuestos = "";
         var resultadoRepuestosSeleccionados = @json($repuestos_solicitados);
         var totalNetoCompra = 0;
         var TotalCompra = 0;
         var TotalPorcentajeCompra = 0;
         var TotalPorcentajeDescuento = @json($ordenes_trabajos[0]->descuento_porcentaje);
         var totalAbono = @json($ordenes_trabajos[0]->abono);
         var metodoDePago = "";
         var repuestoServicioId = "";
         var repuestos_medidas = @json($repuestos_medidas);
         var idServicioGlobal = "";
         var skuServicioGlobal = "";
        var isActiveDescuentoEntero = false;

         console.log("var globales");
         console.log(resultadoServiciosSeleccionados);



           
        function actualizarTable(id){
            var isChecked = $('#check_' + id).prop('checked');
                if (isChecked) {

                     if(id == 20) //id del repuesto OTRO
                     {
                        $('#check_' + id).prop('checked', false); // Desmarca el checkbox

                     }
                    // console.log('El checkbox está marcado');
                    agregarRepuesto(id);

                    // Realiza las acciones que necesites si el checkbox está marcado
                } else {
                    // console.log('El checkbox no está marcado');
                    // agregarRepuesto(id);
                    eliminarFilaRepuesto(id);
                    // Realiza las acciones que necesites si el checkbox no está marcado
                }
        }
         function limpiar() {

             $("#campoServicio").val("");
             $("#nombredelservicio").val("");
             $("#campoServicioDescripcion").val("");
             $("#campoServicioCantidad").val("");

         }
         function funcionPorcentajeAplicadoPesos(event){

            if (event.key === 'Enter') {

            $("#modalDescuentoTotal").modal("hide");

            aplicarDescuentoTotal();

            }
            }

function funcionPorcentajeAplicado(event){

        if (event.key === 'Enter') {

        $("#modalDescuento").modal("hide");

    aplicarDescuento();
}
}



         function buscarServicioFunction(event) {




             if (event.key === 'Enter') {
                 getId = $("#campoServicio").val();

                 if (getId == "") {
                     limpiar();
                 }

                 var data = @json($servicios);
                 //eliminar espacios
                 getId = getId.replace(/\s/g, '');
                 var servicioSele = data.find(servicio => servicio.sku === getId);



                 if (servicioSele) {
                     console.log("El servicio existe:", servicioSele);
                     $("#nombredelservicio").val(servicioSele.nombre_servicio);
                     $("#campoServicioDescripcion").focus();

                     idServicioGlobal = servicioSele.id;
                     skuServicioGlobal = servicioSele.sku;




                 } else {
                     $("#campoServicio").focus();
                     // console.log("No se encontró ningún servicio con el SKU:", getId);
                     alert("SKU no encontrado")
                 }
                 console.log(servicioSele);
                 // console.log(data);
                 // // const buscarServicio = data.findIndex(objeto => objeto.id === getId);
                 // const buscarServicio = data.find(objeto => objeto.id === getId);

                 // console.log(buscarServicio);
                 //  $("#campoServicioDescripcion").focus();

             }
         }
         function agregarBuscador(sku) {
        
        // $("#modalSelectServicios").hide();
        $("#modalSelectServicios").modal("hide");
        $("#campoServicio").val(sku);
         $("#campoServicio").focus();
        

    }
         function buscarServicioFunctionDesc(event) {

             if (event.key === 'Enter') {

                 $("#campoServicioCantidad").focus();

             }
         }

         function buscarServicioFunctionCan(event) {

             if (event.key === 'Enter') {

                 //  var campoServicioSku = $("#campoServicio").val();
                 var campoServicioDescripcion = $("#campoServicioDescripcion").val();
                 var campoServicioCantidad = $("#campoServicioCantidad").val();

                 agregar2(idServicioGlobal, skuServicioGlobal, campoServicioDescripcion, campoServicioCantidad)
                 $("#campoServicio").focus();

             }
         }

         function eliminarFilaRepuesto(dataId) {
             const buscarRepuesto = resultadoRepuestosSeleccionados.findIndex(objeto => objeto.id === dataId);

             if (buscarRepuesto !== -1) {
                 // Si el objeto con "id" 5 existe, eliminarlo
                 resultadoRepuestosSeleccionados.splice(buscarRepuesto, 1);
                 calcularTotalTableRepuestos();
             }
         }

         function eliminarFilaServicio(dataId) {
             const buscarServicio = resultadoServiciosSeleccionados.findIndex(objeto => objeto.id === dataId);

             if (buscarServicio !== -1) {
                 // Si el objeto con "id" 5 existe, eliminarlo
                 resultadoServiciosSeleccionados.splice(buscarServicio, 1);
                 calcularTotalTable();
             }
         }

         function aplicarAbono() {

             totalAbono = $("#abono").val();
             // $("#l_descuento").text(descuentoPorcentaje+"%");
             calcularTotalTable();
             

         }

         function aplicarDescuentoTotal() {

            dscuentoTotalAplicadoT = $("#dscuentoTotalAplicadoT").val();
            isActiveDescuentoEntero = true;
            // $("#l_descuento").text(descuentoPorcentaje+"%");
            calcularTotalTable(1);
            }

         function aplicarDescuento() {

             TotalPorcentajeDescuento = $("#porcentajeAplicado").val();
             // $("#l_descuento").text(descuentoPorcentaje+"%");
             calcularTotalTable();
            isActiveDescuentoEntero = false;


         }

         function openModalRepuestos(idRepuestosSolicitado) {


             $.ajax({

                 headers: {
                     'X-CSRF-TOKEN': $('meta[name="csrf-token"]').attr('content')
                 },
                 type: 'GET',
                 url: "{{ route('historialrepuestos') }}",
                 data: {
                     'idrepuestossolicitados': idRepuestosSolicitado
                 },
                 success: function(data) {
                     //1 rut existe
                     console.log("repuestos data");

                     console.log(data);

                     var tablaBody = $('#tablaBodyRepuestos');
                     tablaBody.empty();

                     // Recorrer los datos y agregar filas a la tabla
                     $.each(data, function(index, item) {
                         var fila = '<tr>' +
                             '<td>' + item.id + '</td>' +
                             '<td>' + formatfecha(item.fecha_recibida) + '</td>' +
                             '<td>' + "<strong>Recibido por:</strong> " + item.recibidopor +
                             "<br> <strong>comentario:</strong>  " + item.comentario + '</td>' +
                             // '<td>' + item.servicios_ordenes_id + '</td>' +
                             '</tr>';
                         tablaBody.append(fila);
                     });

                     //alert("Operación Exitosa");
                     //  window.location.reload();
                     $('#modalHistorialRepustos').show();


                 },
                 error: function(xhr, status) {
                     alert('Disculpe, Ha ocurrido un problema, Intente mas tarde');
                 }
             });

             // tablaBodyRepuestos
         }

         function closedModalRepuestos() {
             $('#modalHistorialRepustos').hide();
         }

         // modalHistorial
         function openhistorial(idServicio) {


             $.ajax({

                 headers: {
                     'X-CSRF-TOKEN': $('meta[name="csrf-token"]').attr('content')
                 },
                 type: 'GET',
                 url: "{{ route('historialservicios') }}",
                 data: {
                     'idServicio': idServicio
                 },
                 success: function(data) {
                     //1 rut existe
                     console.log(data);

                     var tablaBody = $('#tablaBody');
                     tablaBody.empty();

                     // Recorrer los datos y agregar filas a la tabla
                     $.each(data, function(index, item) {
                         var fila = '<tr>' +
                             '<td>' + item.id + '</td>' +
                             '<td>' + formatfecha(item.fecha_ingresado) + '</td>' +
                             '<td>' + item.descripcion + '</td>' +
                             // '<td>' + item.servicios_ordenes_id + '</td>' +
                             '</tr>';
                         tablaBody.append(fila);
                     });

                     //alert("Operación Exitosa");
                     //  window.location.reload();
                     $('#modalHistorial').show();


                 },
                 error: function(xhr, status) {
                     alert('Disculpe, Ha ocurrido un problema, Intente mas tarde');
                 }
             });

         }


         function cerrarmodalhistorial() {
             // alert(idRepuestosServicio);
             $('#modalHistorial').hide();

         }

         //   ....
         function addRepuestos(idRepuestosServicio) {
             // alert(idRepuestosServicio);
             repuestoServicioId = idRepuestosServicio;
             $('#modalRepuestos').show();

         }

         function cerrarmodal(idRepuestosServicio) {
             // alert(idRepuestosServicio);
             $('#modalRepuestos').hide();

         }

         function updaterepuestos() {
             var entregado = "si";
             var comentario = $('#comentario_entrega').val();
             var recibidopor = $('#recibidopor').val();



             // // Verificar si el checkbox está seleccionado
             // if ($('#checkentregado').is(':checked')) {
             //     // El checkbox está seleccionado
             //     entregado = "si";
             // } else {
             //     // El checkbox no está seleccionado
             //     entregado = "no";;
             // }

             $.ajax({

                 headers: {
                     'X-CSRF-TOKEN': $('meta[name="csrf-token"]').attr('content')
                 },
                 type: 'POST',
                 url: "{{ route('update.updaterepuestosorden') }}",
                 data: {
                     'repuestoServicioId': repuestoServicioId,
                     "entregado": entregado,
                     'comentario': comentario,
                     'recibidopor': recibidopor
                 },
                 success: function(data) {
                     //1 rut existe
                     console.log(data);
                     if (data == "ok") {
                         // alert("Operación Exitosa");
                         window.location.reload();
                     }

                 },
                 error: function(xhr, status) {
                     alert('Disculpe, Ha ocurrido un problema, Intente mas tarde');
                 }
             });
         }

         function updateservicio(id_ejecucion_servicio, id_servicio_orden, accion) {

             $.ajax({
                 //  headers: { 'X-CSRF-TOKEN': $('meta[name="csrf-token"]').attr('content') },
                 //  type: 'post',
                 //  url: "{{ route('update.iniciarservicio') }}",
                 //  data: { 'idservicio': id_servicio_orden },
                 headers: {
                     'X-CSRF-TOKEN': $('meta[name="csrf-token"]').attr('content')
                 },
                 type: 'POST',
                 url: "{{ route('update.iniciarservicio') }}",
                 data: {
                     'id_ejecucion_servicio': id_ejecucion_servicio,
                     "id_servicio_orden": id_servicio_orden,
                     'accion': accion
                 },
                 success: function(data) {
                     //1 rut existe
                     if (data == "ok") {
                         // alert("Operación Exitosa");
                         window.location.reload();
                     }
                     // console.log("data");
                     // console.log(data);
                 },
                 error: function(xhr, status) {
                     alert('Disculpe, Ha ocurrido un problema, Intente mas tarde');
                 }
             });
         }

         function agregarRepuesto(data) {


            console.log("DATATDAAA");
            console.log(data);
            
             $('#tablerepuestos').empty();
             $('#nombre_repuesto').val("");
             const min = 10000;
            const max = 20000;
            const allRepuestos =   @json($repuestos);


            const randomNumber = Math.floor(Math.random() * (max - min + 1)) + min;
            // const repuestoSeleccionado = resultadoRepuestos.find(objeto => objeto.id === data);
            const repuestoSeleccionado = allRepuestos.find(objeto => objeto.id === data);

            if(repuestoSeleccionado.nombre == "OTRO"){
                repuestoSeleccionado.id = repuestoSeleccionado.id+randomNumber;
            }
            repuestoSeleccionado.cantidad = 1;
            repuestoSeleccionado.descripcion_repuestos_otro = ""; 
            repuestoSeleccionado.descripcion_medida_otro = ""; 


             // console.log(resultadoServicios);
            //  const repuestoSeleccionado = resultadoRepuestos.find(objeto => objeto.id === data);

            //  repuestoSeleccionado.cantidad = 1;
             // servicioSeleccionado.total= servicioSeleccionado.precio_neto * 1;
             //guardamos en un array

             console.log("aaaaa Revisar::");
             console.log(repuestoSeleccionado.id);

             const buscarRepuesto = resultadoRepuestosSeleccionados.find(objeto => objeto.id === repuestoSeleccionado.id);

             if (buscarRepuesto) {

                 buscarRepuesto.cantidad = buscarRepuesto.cantidad + 1;
             } else {
                 resultadoRepuestosSeleccionados.push(repuestoSeleccionado);

             }

             calcularTotalTableRepuestos();
             // $('#tabla_servicios_selecionados').append('<tr><td>' + servicioSeleccionado.nombre_servicio + '</td></tr>');

             //console.log(repuestoSeleccionado);
         }

         function handleSelectChange(id) {
             idSelect = "#miSelect" + id;
             var valorSele = $(idSelect).val();
             $.each(resultadoRepuestosSeleccionados, function(index, objeto) {
                 if (objeto.id === id) {

                     objeto.valor = valorSele; // Puedes establecer cualquier valor inicial para "cantidad"
                     // calcularTotalTableRepuestos();
                     $('#arrayDatosTablaRepuestos').val(JSON.stringify(resultadoRepuestosSeleccionados));

                 }
             });

         }

         function calcularTotalTableRepuestos() {
             $('#tabla_repuesto_selecionados').empty();
             console.log("resultadoRepuestosSeleccionados");
             console.log(resultadoRepuestosSeleccionados);

             $.each(resultadoRepuestosSeleccionados, function(index, objeto) {


                 // var opcionesArray = ["Opción 1", "Opción 2", "Opción 3"];
                 var opcionesArray = repuestos_medidas.filter(function(opcion) {
                     return opcion.id_repuestos === objeto
                         .id; // Puedes cambiar este valor según tus necesidades
                 });



                //  var tr = "<tr>";
                //  tr += "<td>" + (objeto.nombre || '').toUpperCase() + "</td>";

                var tr = "<tr>";

                if(objeto.nombre != "OTRO"){
                    tr += "<td>" + (objeto.nombre || '').toUpperCase() + "</td>";
                   
                }else{
                    // alert(objeto.descripcion_repuestos_otro);
                    console.log("IDIDIDIDIDIDIDI");
                    console.log(objeto.id);

                    if(objeto.id== 20 ){ //id del objeto otro
                        const min = 10000;
                         const max = 20000;
                        const randomNumber = Math.floor(Math.random() * (max - min + 1)) + min;

                        objeto.id  = objeto.id+randomNumber;
                     }
                        tr += "<td>" + "<input type='text' onchange='agregarDescripcioncOtro("+objeto.id+",this)'  id=descrip_repuesto"+objeto.id+"  value="+"'"+objeto.descripcion_repuestos_otro+"'"+">" + "</td>";
                    
                }
                if(objeto.nombre != "OTRO"){

                        tr += "<td><select id='miSelect" + objeto.id + "' onchange='handleSelectChange(" + objeto.id +
                            ")' >";

                        for (var i = 0; i < opcionesArray.length; i++) {

                            if ('valor' in objeto) {
                                // alert("jj");

                                if (objeto.valor == opcionesArray[i]["id"]) {
                                    tr += "<option selected  value='" + opcionesArray[i]["id"] + "'>" + opcionesArray[i][
                                        "medida"
                                    ] + "</option>";

                                } else {
                                    tr += "<option value='" + opcionesArray[i]["id"] + "'>" + opcionesArray[i]["medida"] +
                                        "</option>";

                                }

                            } else {

                                tr += "<option value='" + opcionesArray[i]["id"] + "'>" + opcionesArray[i]["medida"] +
                                    "</option>";

                                if (i == 0) {
                                    objeto.valor = opcionesArray[i]["id"];
                                }

                            }
                        }

                 tr += "</select>" + "</td>";

         }else{
                 
                 tr += "<td>" + "<input type='text' onchange='agregarMedidaOtro("+objeto.id+",this)'  id=medida_repuesto"+objeto.id+"  value="+"'"+objeto.descripcion_medida_otro+"'"+">" + "</td>";
                 
             }



                 tr += "<td>" + (objeto.categoria || '').toUpperCase() + "</td>";
                 tr += "<td>" + "<input type='button' value='-'  onclick='restar_repuesto(" + objeto.id + ")' >" +
                     "<input  type='text' onchange='cambiodevalormanualrepuestos(" + objeto.id +
                     ",this)' onkeypress='soloNumeros(event)' class='narrow-input' value='" + objeto.cantidad +
                     "' id='valores_repuestos" + objeto
                     .id + "'>" + "<input type='button' onclick='sumar_repuesto(" + objeto.id + ")'  value='+'>" +
                     "</td>";

                 tr += "<td>" + '<a  onclick="eliminarFilaRepuesto(' + objeto.id + ')"  >' + "Eliminar" + "</a>" +
                     "</td>";
                 tr += "</tr>";

                 $('#tabla_repuesto_selecionados').append(tr);

             });
             $('#arrayDatosTablaRepuestos').val(JSON.stringify(resultadoRepuestosSeleccionados));



         }

         function registrarTecnico(idServicioAsociado, id_servicio_orden) {


             $('#modalAddTecnico').show();
             $('#identificador_servicio_eje').val(idServicioAsociado);
             $('#id_servicio_orden').val(id_servicio_orden);




             // $.ajax({
             //     headers: { 'X-CSRF-TOKEN': $('meta[name="csrf-token"]').attr('content') },
             //     type: 'GET',
             //     url: "{{ route('update.updateservicioorden') }}",
             //     data: { 'idservicio': idServicioAsociado },
             //     success: function(data) {
             //        //1 rut existe
             //        console.log("data");
             //        console.log(data);
             //     },
             //     error: function(xhr, status) {
             //         alert('Disculpe, Ha ocurrido un problema, Intente mas tarde');
             //     }
             // });


         }

         function cerrarModal() {

             $('#modalAddTecnico').hide();

         }

         //  function agregar2(data) {
         function agregar2(idSer, skuSer, desSer, canSer) {

             $('#tableservicios').empty();
             $('#nombre_servicio').val("");

             var data = @json($servicios);

             //eliminar espacios

             // console.log(resultadoServicios);
             //  const servicioSeleccionado = resultadoServicios.find(objeto => objeto.id === data);

             //  servicioSeleccionado.cantidad = 1;
             const servicioSeleccionado = data.find(objeto => objeto.id === idSer);

             if (canSer == "" || canSer <= 0) {
                 canSer = 1;
             }

             servicioSeleccionado.cantidad = canSer;
             servicioSeleccionado.descripcionservicio = desSer;
             // servicioSeleccionado.total= servicioSeleccionado.precio_neto * 1;
             //guardamos en un array

             const buscarServicio = resultadoServiciosSeleccionados.find(objeto => objeto.id === servicioSeleccionado.id);

             if (buscarServicio) {

                 //  buscarServicio.cantidad = buscarServicio.cantidad + 1;
                 buscarServicio.cantidad = parseFloat(buscarServicio.cantidad) + parseFloat(1);

             } else {
                 resultadoServiciosSeleccionados.push(servicioSeleccionado);

             }
             // resultadoServiciosSeleccionados.push(servicioSeleccionado);

             calcularTotalTable();
             // $('#tabla_servicios_selecionados').append('<tr><td>' + servicioSeleccionado.nombre_servicio + '</td></tr>');

             console.log(servicioSeleccionado);
         }

         function agregarDescripcion(id, inputElement) {
             var nuevoValor = inputElement.value;
             $.each(resultadoServiciosSeleccionados, function(index, objeto) {
                 if (objeto.id === id) {
                     objeto.descripcionservicio =
                         nuevoValor; // Puedes establecer cualquier valor inicial para "cantidad"
                 }
             });

             calcularTotalTable();
         }
         function agregarMedidaOtro(id, inputElement){


var nuevoValor = inputElement.value;

$.each(resultadoRepuestosSeleccionados, function(index, objeto) {
    if (objeto.id === id) {
        objeto.descripcion_medida_otro = nuevoValor; // Puedes establecer cualquier valor inicial para "cantidad"
    }
});
calcularTotalTableRepuestos();

console.log(resultadoRepuestosSeleccionados);
}

         function agregarDescripcioncOtro(id, inputElement){



            var nuevoValor = inputElement.value;
            console.log(id+"____"+nuevoValor);

            $.each(resultadoRepuestosSeleccionados, function(index, objeto) {
                if (objeto.id === id) {
                    objeto.descripcion_repuestos_otro = nuevoValor; // Puedes establecer cualquier valor inicial para "cantidad"
                }
            });
            calcularTotalTableRepuestos();
            console.log(resultadoRepuestosSeleccionados);
            }

         function cambiodevalormanualrepuestos(id, inputElement) {
             var nuevoValor = inputElement.value;
             $.each(resultadoRepuestosSeleccionados, function(index, objeto) {
                 if (objeto.id === id) {
                     objeto.cantidad = nuevoValor; // Puedes establecer cualquier valor inicial para "cantidad"
                 }
             });

             calcularTotalTableRepuestos();
         }
         function cambiodevalormaPrecio(id, inputElement) {
            
            var nuevoValor = inputElement.value;
            $.each(resultadoServiciosSeleccionados, function(index, objeto) {
                if (objeto.id === id) {
                    objeto.precio_neto = nuevoValor; // Puedes establecer cualquier valor inicial para "cantidad"
                }
            });

            calcularTotalTable();
        }


         function sumar_repuesto(data) {
             $.each(resultadoRepuestosSeleccionados, function(index, objeto) {
                 if (objeto.id === data) {
                     objeto.cantidad = parseInt(objeto.cantidad) +
                         1; // Puedes establecer cualquier valor inicial para "cantidad"
                 }
             });


             calcularTotalTableRepuestos();
         }

         function restar_repuesto(data) {
             $.each(resultadoRepuestosSeleccionados, function(index, objeto) {
                 if (objeto.id === data) {

                     if (objeto.cantidad > 1) {
                         objeto.cantidad = objeto.cantidad - 1;
                     }
                     // Puedes establecer cualquier valor inicial para "cantidad"
                 }
             });
             calcularTotalTableRepuestos();

         }

         //servicios
         function sumar(data) {
             $.each(resultadoServiciosSeleccionados, function(index, objeto) {
                 if (objeto.id === data) {
                     objeto.cantidad = parseInt(objeto.cantidad) +
                         1; // Puedes establecer cualquier valor inicial para "cantidad"
                 }
             });

             
             calcularTotalTable();
         }

         function restar(data) {
             $.each(resultadoServiciosSeleccionados, function(index, objeto) {
                 if (objeto.id === data) {

                     if (objeto.cantidad > 1) {
                         objeto.cantidad = objeto.cantidad - 1;
                     }
                     // Puedes establecer cualquier valor inicial para "cantidad"
                 }
             });
             calcularTotalTable();

         }

         function calcularTotalTable(activardescuento = 0) {

             $('#tabla_servicios_selecionados').empty();
             //limpiamos los campos
             $("#campoServicio").val("");
             $("#nombredelservicio").val("");
             $("#campoServicioDescripcion").val("");
             $("#campoServicioCantidad").val("");

             idServicioGlobal = "";
             skuServicioGlobal = "";
             // fin de la limpieza
             var tipoUsuario = @json(\App\Models\User::tipoUsuario());

             descuento_pesos = @json($descuento_pesos);
             var total = 0;
             var neto = 0;

             console.log("resultadoServiciosSeleccionados");

             console.log(resultadoServiciosSeleccionados);
             $.each(resultadoServiciosSeleccionados, function(index, objeto) {

                 if (objeto.descripcionservicio === null || objeto.descripcionservicio === undefined) {
                     objeto.descripcionservicio = "";
                 }

                 objeto.total = objeto.precio_neto * objeto.cantidad;

                 total = total + objeto.total;
                 neto = neto + objeto.precio_neto * objeto.cantidad;

                 console.log(neto + "+" + objeto.precio_neto + "*" + objeto.cantidad);
                 objeto.estado_ejecucion = "ingresado";
                 var tr = "<tr>";
                 tr += "<td>" + (objeto.sku || '').toUpperCase() + "</td>";

                 tr += "<td>" + (objeto.nombre_servicio || '').toUpperCase() + "</td>";
                 // tr += "<td>" + (objeto.descripcionservicio || '').toUpperCase() + "</td>";
                 tr += "<td>" + "<input class='text-uppercase' value='" + objeto.descripcionservicio +
                     "' type='text' onchange='agregarDescripcion(" + objeto.id + ",this)' >" + "</td>";


                 tr += "<td>" + (objeto.nombre_categoria || '').toUpperCase() + "</td>";
                 tr += "<td>" + "<input type='button' value='-'  onclick='restar(" + objeto.id + ")' >" +
                     "<input type='text' onchange='cambiodevalormanual(" + objeto.id +
                     ",this)' class='narrow-input' onkeypress='soloNumeros(event)' value='" + objeto.cantidad +
                     "' id='valores" + objeto
                     .id + "'>" + "<input type='button' onclick='sumar(" + objeto.id + ")'  value='+'>" + "</td>";


                //  tr += "<td>" + formatNumberWithCommas(objeto.precio_neto) + "</td>";
                // if(objeto.precio_editable == 1 && (tipoUsuario == "superadmin" || tipoUsuario == "admin")  ){

                if(objeto.precio_editable == 1  ){
                            tr += "<td>" + "<input type='number' onchange='cambiodevalormaPrecio(" + objeto.id +",this)'   value='"+objeto.precio_neto+"'>" + "</td>";

                        }else{
                            tr += "<td>" + formatNumberWithCommas(objeto.precio_neto) + "</td>";

                }


                 //  tr += "<td>" + 2+"</td>";

                 tr += "<td>" + formatNumberWithCommas(objeto.total) + "</td>";
                 tr += "<td>" + objeto.estado_ejecucion + "</td>";

                //  tr += "<td>" + '<a  onclick="eliminarFilaServicio(' + objeto.id + ')"  >' + '<i class="fas fa-trash-alt"></i>'+ "</a>" +
                //      "</td>";
                tr += "<td>" + '<a  style="cursor:pointer" onclick="eliminarFilaServicio(' + objeto.id + ')" >' + ' <span class="material-symbols-outlined">delete</span>' + "</a>"+"</td>";;
               

                 tr += "</tr>";

                 $('#tabla_servicios_selecionados').append(tr);

             });
             $('#arrayDatosTabla').val(JSON.stringify(resultadoServiciosSeleccionados));




             //SUB TOTAL
             $("#l_subtotal").text(formatNumberWithCommas(neto));
             //IMPUESTO AL SUBTOTAL 
             l_impuestoTotal = (neto * 19) / 100;
             $("#l_impuestoTotal").text(formatNumberWithCommas(l_impuestoTotal));

             //TOTAL MAS IMPUESTO
             l_totalmasimpuesto = neto + l_impuestoTotal;
             $("#l_totalmasimpuesto").text(formatNumberWithCommas(l_totalmasimpuesto));

             if(activardescuento != 0 || isActiveDescuentoEntero == true){

                        if(dscuentoTotalAplicadoT != 0){
                            console.log("entreee");
                            var paso_1 = dscuentoTotalAplicadoT * 100;
                            // var paso_2 = paso_1 / neto;
                            var paso_2 = parseFloat((paso_1 / l_totalmasimpuesto).toFixed(4));
                            $("#l_descuento_sin_porcentaje").text(formatNumberWithCommas(dscuentoTotalAplicadoT));

                            console.log("l_descuento_sin_porcentaje");
                            console.log(dscuentoTotalAplicadoT);
                            TotalPorcentajeDescuento  = paso_2

                            
                        }
            }

            var descuento = (l_totalmasimpuesto * TotalPorcentajeDescuento) / 100;


            // //DESCUENTO POR PORCENTAJE
            // var nuevoPorcentaje =  (descuento_pesos * 100)/ l_totalmasimpuesto;
            // TotalPorcentajeDescuento = nuevoPorcentaje;


                var descuento = (l_totalmasimpuesto * TotalPorcentajeDescuento) / 100;

             //TOTAL CON DESCUENTOS
             l_totalcondescuento = l_totalmasimpuesto - descuento;
             $("#l_totalcondescuento").text(formatNumberWithCommas(l_totalcondescuento));


     

             getData = calcularIVA(l_totalcondescuento, 19);
             $("#l_totalnetoNuevo").text(formatNumberWithCommas(getData.neto));

             $("#l_impuestoTotalNuevo").text(formatNumberWithCommas(getData.impuesto));

             //PENDIENTE
             totalMenosDescuentos = l_totalcondescuento - totalAbono;
             $("#l_pendiente").text(formatNumberWithCommas(totalMenosDescuentos));

             
   //calculamos los totales

            // Calcular el descuento

            var descuentoSinPorcentaje = dscuentoTotalAplicadoT;


            // Calcular el nuevo precio después del descuento totalAbono
            var precioConDescuento = l_totalmasimpuesto - descuento;

            if(activardescuento == 0){

                
                
                $("#l_descuento_sin_porcentaje").text(formatNumberWithCommas(l_totalmasimpuesto-precioConDescuento));

           }


            //  var precioConDescuento = l_totalmasimpuesto - descuento;


            
            // $("#l_descuento").text(nuevoPorcentaje + "%");

            // $("#input_descuento").val(nuevoPorcentaje);

            $("#l_descuento").text(TotalPorcentajeDescuento + "%");
            $("#l_descuentoTotal").text(formatNumberWithCommas(descuento));
            $("#l_abono").text(formatNumberWithCommas(totalAbono));


  //setiamos los pagos para enviarlos por el formulario
  $("#input_abono").val(totalAbono);
            $("#input_descuento").val(TotalPorcentajeDescuento);
            $("#input_metodopago").val(metodoDePago);

         }


         $(document).ready(function() {

             //evitar enviar formulario
             $('#formuarioeditar').on('keydown', function(e) {
                 if (e.key === 'Enter') {
                     e.preventDefault(); // Evitar el envío del formulario
                 }
             });
             $("#searchInput").on("input", function () {
            var value = $(this).val().toUpperCase();
            $("#tableservicios tr").filter(function () {
                $(this).toggle($(this).text().toUpperCase().indexOf(value) > -1);
            });
        });
             //validar que si queda vacio, se elminen todos los datos
             $('#campoServicio').on('keyup', function() {

                 getId = $("#campoServicio").val();

                 if (getId == "") {
                     limpiar();
                 }
             });
             calcularTotalTable();

             calcularTotalTableRepuestos();

             // Agrega un manejador de eventos para el evento keyup
             $('#nombre_servicio').on('keyup', function() {

                 console.log(2);
                 // Obtiene el valor del campo de entrada
                 var valorIngresado = $(this).val();

                 var data = @json($servicios);

                 console.log(data);
                 // Obtener el texto de búsqueda por teclado
                 // var valorIngresado = prompt("Ingrese una letra para buscar servicios:");

                 // Filtrar los elementos por nombre o SKU que contengan la letra ingresada
                 resultadoServicios = $.grep(data, function(servicio) {
                     // Comparar el nombre y el SKU en minúsculas para que la búsqueda sea insensible a mayúsculas/minúsculas
                     var nombreLowerCase = servicio.nombre_servicio.toLowerCase();
                     var skuLowerCase = servicio.sku.toLowerCase();
                     var letraBusqueda = valorIngresado.toLowerCase();

                     return nombreLowerCase.includes(letraBusqueda) || skuLowerCase.includes(
                         letraBusqueda);
                 });

                 $('#tableservicios').empty();

                 if (valorIngresado != "") {

                     $(resultadoServicios).each(function(i, v) {
                         $('#tableservicios').append(
                             '<tr><td class="agregar" onclick="agregar2(' + v.id + ')">' + v
                             .sku + " ||  " + v
                             .nombre_servicio.toUpperCase() + '</td></tr');
                     })
                 } else {
                     $('#tableservicios').empty();

                 }
                 console.log(resultadoServicios);


             });


             // Agrega un manejador de eventos para el evento keyup
             $('#nombre_repuesto').on('keyup', function() {
                 // Obtiene el valor del campo de entrada
                 var valorIngresado = $(this).val();

                 var data = @json($repuestos);


                 // Obtener el texto de búsqueda por teclado
                 // var valorIngresado = prompt("Ingrese una letra para buscar servicios:");

                 // Filtrar los elementos por nombre o SKU que contengan la letra ingresada
                 resultadoRepuestos = $.grep(data, function(servicio) {
                     // Comparar el nombre y el SKU en minúsculas para que la búsqueda sea insensible a mayúsculas/minúsculas
                     var nombreLowerCase = (servicio.nombre || '').toLowerCase();
                     var skuLowerCase = (servicio.categoria || '').toLowerCase();
                     var letraBusqueda = valorIngresado.toLowerCase();

                     return nombreLowerCase.includes(letraBusqueda) || skuLowerCase.includes(
                         letraBusqueda);
                 });


                 $('#tablerepuestos').empty();

                 if (valorIngresado != "") {

                     $(resultadoRepuestos).each(function(i, v) {
                         $('#tablerepuestos').append(
                             '<tr><td class="agregar" onclick="agregarRepuesto(' + v.id + ')">' +
                             v
                             .nombre.toUpperCase() + '</td></tr');
                     })
                 } else {
                     $('#tablerepuestos').empty();

                 }
                 // console.log(resultadoServicios);


             });

         });


         function calcularIVA(valorBruto, tasaIVA) {
                 // Convierte la tasa de IVA a un decimal dividiéndola por 100
                 var tasaDecimal = (tasaIVA / 100) + 1;

                 // Calcula el monto del IVA
                 neto = valorBruto / tasaDecimal;

                 impuesto = valorBruto - neto;



                 return {
                     neto: neto,
                     impuesto: impuesto
                 };
             }
     </script>
 @endsection
